summaryrefslogtreecommitdiff
path: root/src/strgen/strgen.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/strgen/strgen.h')
-rw-r--r--src/strgen/strgen.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/strgen/strgen.h b/src/strgen/strgen.h
index 22b24a266..ecae71a72 100644
--- a/src/strgen/strgen.h
+++ b/src/strgen/strgen.h
@@ -72,10 +72,10 @@ struct StringReader {
/**
* Read a single line from the source of strings.
* @param buffer The buffer to read the data in to.
* @param size The size of the buffer.
* @return The buffer, or NULL if at the end of the file.
*/
- virtual char *ReadLine(char *buffer, size_t size) = 0;
+ virtual char *ReadLine(char *buffer, const char *last) = 0;
/**
* Handle the pragma of the file.
@@ -72,10 +72,10 @@ struct StringReader {
* Read a single line from the source of strings.
* @param buffer The buffer to read the data in to.
- * @param size The size of the buffer.
+ * @param last The last element in the buffer.
* @return The buffer, or NULL if at the end of the file.
*/